@@ -47,6 +47,8 @@
 #include <private/xdgiconloader/xdgiconloader_p.h>
 #include <QLibrary>
 
+#include <utility>
+
 
 // Function to create a new Fm::FileDialogHelper object.
 // This is dynamically loaded at runtime on demand from libfm-qt.
@@ -111,6 +113,11 @@ void LXQtPlatformTheme::loadSettings() {
     else
         toolButtonStyle_ = static_cast<Qt::ToolButtonStyle>(value);
 
+    // toolbar icon size
+    toolBarIconSize_ = qBound(0, settings.value(QLatin1String("tool_bar_icon_size")).toInt(), 48);
+    if (toolBarIconSize_ < 16)
+        toolBarIconSize_ = 0; // let the style decide
+
     // single click activation
     singleClickActivate_ = settings.value(QLatin1String("single_click_activate")).toBool();
 
@@ -159,6 +166,16 @@ void LXQtPlatformTheme::loadSettings() {
     if (!paletteChanged_)
         paletteChanged_ = linkVisitedColor_.isValid() && color != linkVisitedColor_;
 
+    color = tooltipBaseCol_;
+    tooltipBaseCol_ = QColor::fromString(settings.value(QLatin1String("tooltip_base_color")).toString());
+    if (!paletteChanged_)
+        paletteChanged_ = tooltipBaseCol_.isValid() && color != tooltipBaseCol_;
+
+    color = tooltipTextCol_;
+    tooltipTextCol_ = QColor::fromString(settings.value(QLatin1String("tooltip_text_color")).toString());
+    if (!paletteChanged_)
+        paletteChanged_ = tooltipTextCol_.isValid() && color != tooltipTextCol_;
+
     if(paletteChanged_)
     {
         delete LXQtPalette_;
@@ -222,6 +239,10 @@ void LXQtPlatformTheme::loadSettings() {
             LXQtPalette_->setColor(QPalette::Link, linkColor_);
         if (linkVisitedColor_.isValid())
             LXQtPalette_->setColor(QPalette::LinkVisited, linkVisitedColor_);
+        if (tooltipBaseCol_.isValid())
+            LXQtPalette_->setColor(QPalette::ToolTipBase, tooltipBaseCol_);
+        if (tooltipTextCol_.isValid())
+            LXQtPalette_->setColor(QPalette::ToolTipText, tooltipTextCol_);
     }
     settings.endGroup();
 
@@ -442,7 +463,7 @@ QVariant LXQtPlatformTheme::themeHint(ThemeHint hint) const {
     case ToolButtonStyle:
         return QVariant(toolButtonStyle_);
     case ToolBarIconSize:
-        break;
+        return QVariant(toolBarIconSize_);
     case ItemViewActivateItemOnSingleClick:
         return QVariant(singleClickActivate_);
     case SystemIconThemeName:
@@ -519,7 +540,7 @@ QStringList LXQtPlatformTheme::xdgIconThemePaths() const
         xdgDataDirs = QLatin1String("/usr/local/share/:/usr/share/");
     xdgDirs.append(xdgDataDirs);
 
-    for (const auto &s: xdgDirs) {
+    for (const auto &s: std::as_const(xdgDirs)) {
         const QStringList r = s.split(QLatin1Char(':'), Qt::SkipEmptyParts);
         for (const auto& xdgDir: r) {
             const QFileInfo xdgIconsDir(xdgDir + QStringLiteral("/icons"));
