@@ -92,6 +92,7 @@ private:
     // LXQt settings
     QString iconTheme_;
     Qt::ToolButtonStyle toolButtonStyle_;
+    int toolBarIconSize_;
     bool singleClickActivate_;
     bool iconFollowColorScheme_;
 
@@ -100,7 +101,8 @@ private:
     QString style_;
     QColor winColor_, baseColor_, highlightColor_,
            winTextColor_, textColor_, highlightedTextColor_,
-           linkColor_, linkVisitedColor_;
+           linkColor_, linkVisitedColor_,
+           tooltipBaseCol_, tooltipTextCol_;
     bool paletteChanged_;
     QString fontStr_;
     QFont font_;
